Welcome!
========

This library contains the components required to integrate an
OpenStack deployment with an Arista Networks Converged Cloud Fabric.

* Source: https://opendev.org/x/networking-bigswitch
* Bugs: https://bugs.launchpad.net/networking-bigswitch


External Resources:
===================

Arista Networks Website: http://www.arista.com
